@@ -493,98 +493,6 @@ def pretile_scoring(slide_file_path: str, output_dir: str, annotation_table_path
 
     return properties
 
-
-### MAIN ENTRY METHOD -> pretile
-def run_model(pil_file_path: str, csv_file_path: str, output_dir: str, params: dict) -> dict:
-    """runs a tile classifier model on a tile data frame/csv
-    
-    Loads a PyTorch model and runs inference on a set of tiles in an input dataframe. 
-    The results are saved to an output csv. 
-
-    to_mag_scale_factor tells us how much to scale to get from full resolution to
-    desired magnification. to_thumbnail_scale_factor tells us how much to scale to get
-    from desired magnification to the desired thumbnail downscale, relative to requested
-    mag. The tile size is defined at the requested mag, so it's bigger at full resolution
-    and smaller for the thumbnail. to_mag_scale_factor and to_thumbnail_scale_factor both
-    need to be event integers, i.e. the scale factors are multiples of the the scanned
-    magnficiation
-
-    Args:
-        pil_file_path (str): file path to the input whole slide 
-        csv_file_path (str): input tile csv/dataframe 
-        output_dir (str): destination to save inference results to 
-        params (dict): configuration dictionary consisting of model_package, which
-            properties of the tile classifier model 
-
-    Returns:
-        properties (dict): a properties dictionary with return values 
-        
-    """ 
-    model_package             = params.get("model_package")
-
-    # load csv
-    df_tiles_to_process = pd.read_csv(csv_file_path)
-
-    logger.info(f"BUILDING MODEL FROM {model_package}..")
-    
-    tile_model = importlib.import_module(model_package)
-    classifier = tile_model.get_classifier ( **params['model'] )
-    transform  = tile_model.get_transform ()
-
-    classifier.eval()
-    classifier.cuda()
-
-    logger.info( classifier )
-
-    logger.info("RUNNING MODEL...")
-
-    counter = 0
-    model_scores = []
-    tumor_score  = []
-    label_score = []
-
-    fp = open(pil_file_path, "rb")
-
-    with torch.no_grad():
-
-        for index, row in df_tiles_to_process.iterrows():
-            counter += 1
-            if counter % 1000 == 0: logger.info( "Proccessing tiles [%s,%s]", counter, len(df_tiles_to_process))
-
-            # TODO load tiles from pil
-            fp.seek(int (row.tile_image_offset))
-            img = Image.frombytes(row.tile_image_mode,
-                                  (int (row.tile_image_size_xy), int (row.tile_image_size_xy)),
-                                  fp.read(int (row.tile_image_length)))
-
-            output = classifier(transform(img).unsqueeze(0).cuda())
-            scores = output.exp() / output.exp().sum()
-
-            model_scores.append( 'Label-' + str( scores.argmax(1).item()) )
-            tumor_score.append( scores.flatten()[0].item() )
-            label_score.append( scores.max().item() )
-            
-    
-    df_tiles_to_process.loc[:, "model_score"] =  model_scores
-    df_tiles_to_process.loc[:, "tumor_score"] =  tumor_score
-    df_tiles_to_process.loc[:, "label_score"] =  label_score
-
-    logger.info(df_tiles_to_process)
-
-    output_file = os.path.join(output_dir, "tile_scores_and_labels_pytorch_inference.csv")
-    df_tiles_to_process.to_csv(output_file)
-
-    logger.info ("Saved tile inference data at %s", output_file)
-
-    properties = {
-        "data": output_file,
-        "total_tiles": len(df_tiles_to_process),
-        "image_filename": Path(pil_file_path).name,
-        "available_labels": list(df_tiles_to_process.columns)
-    }
-
-    return properties 
-
 def create_tile_thumbnail_image(slide_file_path: str, scores_file_path: str, output_dir:
         str, params: dict)-> dict:
     """creates thumbnail images for score visualizations
